package algorithms;

import java.util.List;

import chromosome.Ant;
import selection.ISelection;
import selection.RouletteWheelSelection;


public class TestClass extends MaxMinAntSystem {
	
	
	public TestClass(double[][] distances, int maxIter, int numOfAnts) {
		super(distances, maxIter, numOfAnts);
	}
	

	@Override
	public Integer selectNext(Integer current, List<Integer> visited, List<Integer> available) {
		double[] probabilities = findProbabilities(available, current);
		ISelection selection = new RouletteWheelSelection(probabilities);
		Integer next = selection.selection(available);
		return next;
	}
	

	@Override
	public void calculatefitness(Ant ant) {
		int tourLength = 0;
		for (int i = 0; i < ant.getTour().size() - 1; i++) {
			tourLength += distances[ant.getTour().get(i)][ant.getTour().get(i + 1)];
		}
		
		tourLength += distances[ant.getTour().get(0)][ant.getTour().get(ant.getTour().size() - 1)];
		
		ant.setTourLength(tourLength);
	}
	
	
	private double[] findProbabilities(List<Integer> available, Integer currentCity) {
		double[] probabilities = new double[available.size()];
		for (int i = 0; i < available.size(); i++) {
			probabilities[i] = Math.pow(this.pheromones[currentCity][available.get(i)], ALPHA)
					* this.heuristics[currentCity][available.get(i)];
		}

		return probabilities;
	}


}
