package chromosome;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class Data implements IData{
	private String fileName;
	private List<Point> points;
	private List<Integer> nodes;
	private double[][] distances;

	public Data(String fileName) {
		this.fileName = fileName;
		this.points = new ArrayList<>();
		this.nodes = new ArrayList<>();
	}

	public List<Integer> getNodes() {
		return nodes;
	}

	public double[][] getDistances() {
		return distances;
	}

	public void parse() {
		try (BufferedReader reader = new BufferedReader(new FileReader(fileName))) {
			String line;

			while ((line = reader.readLine()) != null) {
				if (line.startsWith("DISPLAY_DATA_SECTION") || line.startsWith("NODE_COORD_SECTION")) {
					break;
				}
			}

			while (!(line = reader.readLine()).trim().equals("EOF")) {
				String[] parts = line.trim().split("\\s+");
				Point point = new Point(Double.parseDouble(parts[1]), Double.parseDouble(parts[2]));
				points.add(point);
			}

			this.distances = new double[points.size()][points.size()];
			for (int i = 0; i < points.size(); i++) {
				nodes.add(i);
				for (int j = 0; j < points.size(); j++) {
					this.distances[i][j] = calculateDistance(points.get(i), points.get(j));
				}
			}

		} catch (IOException e) {
			System.err.println("File could not be read.");
			System.exit(0);

		}
	}

	private int calculateDistance(Point first, Point second) {
		double xDist = first.getX() - second.getX();
		double yDist =  first.getY() - second.getY();
		return (int)Math.round(Math.sqrt(Math.pow(xDist, 2) + Math.pow(yDist, 2)));
	}

}
